@@ -118,6 +118,7 @@ linkToDirs.pl - hard links files in directories with others
 		      --targetDir targetForSourceDir
 		      [--progressReport number] [--dontLinkSymlinks]
 		      [--ignoreErrors] [--saveRAM] [-T tmpdir]
+		      [--createSparseFiles [--blockSize]]
 		      sourceDir ...
 
 =head1 DESCRIPTION
@@ -172,6 +173,20 @@ linked always in targetDir.
 =item B<--tmpdir>, B<-T>
 
     directory for temporary files, default is </tmp>
+
+
+=item B<--createSparseFiles>, B<-s>
+
+    if a file is indicated as a sparse file and that file has to be
+    copied, then external program 'cp' is called to copy that file
+    (gnucp / linux does some inspection about sparse files, if your
+    OS related version of cp does not support this functionality,
+    then this option will not work for you)
+
+=item B<--blockSize>
+
+    block size used to check if a file is / may be a sparse file
+    default is 512 bytes (which should be fine for most file systems)
     
 =item B<sourceDir>
 
@@ -218,6 +233,14 @@ my $CheckPar =
 					    '-cl_alias' => '--ignoreErrors'),
 				Option->new('-name' => 'saveRAM',
 					    '-cl_option' => '--saveRAM'),
+				Option->new('-name' => 'createSparseFiles',
+					    '-cl_option' => '--createSparseFiles',
+					    '-cl_alias' => '-s'),
+				Option->new('-name' => 'blockSize',
+					    '-cl_option' => '--blockSize',
+					    '-default' => 512,
+					    '-only_if' => '[createSparseFiles]',
+					    '-pattern' => '\A\d+\Z'),
 				Option->new('-name' => 'tmpdir',
 					    '-cl_option' => '-T',
 					    '-cl_alias' => '--tmpdir',
@@ -237,9 +260,10 @@ my $dontLinkSymlinks = $CheckPar->getOptWithoutPar('dontLinkSymlinks');
 my $ignoreErrors = $CheckPar->getOptWithoutPar('ignoreErrors');
 my (@sourceDir) = $CheckPar->getListPar();
 my $saveRAM = $CheckPar->getOptWithoutPar('saveRAM');
+my $createSparseFiles = $CheckPar->getOptWithoutPar('createSparseFiles');
+my $blockSize = $CheckPar->getOptWithPar('blockSize');
 $tmpdir = $CheckPar->getOptWithPar('tmpdir');
 
-
 my $prLog;
 my ($prLogKind) = ['A:BEGIN',
 		   'Z:END',
@@ -528,11 +552,11 @@ foreach my $d (@sourceDir)
 	elsif ($t eq 'f' or $t eq 'l')  # normal file or symlink
 	{
 	    my ($dev, $inode, $mode, $uid, $gid, $size, $atime,
-		$mtime, $ctime);
+		$mtime, $ctime, $blocks);
 	    if ($t eq 'f')
 	    {
 		($dev, $inode, $mode, $uid, $gid, $size, $atime,
-		$mtime, $ctime) = (stat($f))[0,1,2,4,5,7,8,9,10];
+		$mtime, $ctime, $blocks) = (stat($f))[0,1,2,4,5,7,8,9,10,12];
 	    }
 	    elsif ($t eq 'l')
 	    {
@@ -559,7 +583,11 @@ foreach my $d (@sourceDir)
 
 		    if ($t eq 'f')
 		    {
-			unless (&::copyFile($f, $fnew, $prLog))
+#			unless (&::copyFile($f, $fnew, $prLog))
+			unless (&::checkSparseAndCopyFiles(
+				       $f, $fnew, $prLog, $size,
+				       $blocks, $createSparseFiles,
+				       $blockSize, $tmpdir))
 			{
 			    $prLog->print('-kind' => 'E',
 					  '-str' =>
@@ -617,7 +645,11 @@ foreach my $d (@sourceDir)
 
 			if ($t eq 'f')
 			{
-			    unless (&::copyFile($f, $fnew, $prLog))
+#			    unless (&::copyFile($f, $fnew, $prLog))
+			    unless (&::checkSparseAndCopyFiles(
+					   $f, $fnew, $prLog, $size,
+					   $blocks, $createSparseFiles,
+					   $blockSize, $tmpdir))
 			    {
 				$prLog->print('-kind' => 'E',
 					      '-str' =>
@@ -652,7 +684,11 @@ foreach my $d (@sourceDir)
 #print "\tcopy $f =>$fnew\n";
 		    if ($t eq 'f')
 		    {
-			unless (&::copyFile($f, $fnew, $prLog))
+#			unless (&::copyFile($f, $fnew, $prLog))
+			unless (&::checkSparseAndCopyFiles(
+				       $f, $fnew, $prLog, $size,
+				       $blocks, $createSparseFiles,
+				       $blockSize, $tmpdir))
 			{
 			    $prLog->print('-kind' => 'E',
 					  '-str' =>
@@ -743,6 +779,59 @@ else
 exit 0;
 
 
+##################################################
+# retunrs 1 on success, 0 if copy fails
+sub checkSparseAndCopyFiles
+{
+    my $source = shift;
+    my $target = shift;
+    my $prLog = shift;
+    my $size = shift;
+    my $blocks = shift;
+    my $createSparseFiles = shift;
+    my $blockSize = shift;
+    my $tmpdir = shift;
+
+    if ($createSparseFiles and  $blocks * $blockSize < $size) # maybe sparse file
+    {
+	my $ret = 1;   # success
+	my $cp = forkProc->new('-exec' => 'cp',
+			       '-param' =>
+			       ["$source", "$target"],
+			       '-outRandom' => "$tmpdir/linkTo-cp-",
+			       '-prLog' => $prLog);
+	$cp->wait();
+	my $out = $cp->getSTDOUT();
+	if (@$out)
+	{
+	    $prLog->print('-kind' => 'W',
+			  '-str' =>
+			  ["copying of <$source> to <$target> reported:",
+			   @$out]);
+	}
+	$out = $cp->getSTDERR();
+	if (@$out)
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' =>
+		  ["copying (with 'cp -r') of <$source> to <$target> reported:",
+			   @$out]);
+	    $ret = 0;
+	}
+	$prLog->print('-kind' => 'I',
+		      '-str' => ["file <$source> copied as sparse file"])
+	    if $ret;
+
+	return $ret;
+    }
+    else
+    {
+	return &::copyFile($source, $target, $prLog);
+    }
+}
+
+
+
 ##################################################
 package Statistic;
 
