@@ -991,8 +991,7 @@ sub checkMD5
 				  '-str' =>
 				  ["strange line in <$f/.md5BlockCheckSums.bz2> " .
 				   "in line " . $fileIn->get('-what' => 'lineNr') .
-				   ":", "\t<$l>"],
-				  '-exit' => 1)
+				   ":", "\t<$l>"]);
 		}
 
 		if (-e "$dirToCheck/$l_f")
