@@ -134,7 +134,9 @@ no configuration file:
 =item B<--configFile>, B<-f>
 
     (original, non-isolated mode) configuration file to copy for
-    isolated mode also used to get value for backupDir and series
+    isolated mode also used to get value for backupDir and series.
+    You can also use an already generated configuration file to
+    repeat the set up with the same configuration as in the past.
 
 =item B<--targetDir>, B<-t>
 
@@ -211,7 +213,8 @@ my $CheckPar =
 					    '-cl_option' => '-t',
 					    '-cl_alias' => '--targetDir',
 					    '-param' => 'yes',
-					    '-must_be' => 'yes'),
+#					    '-must_be' => 'yes'),
+					    ),
 				Option->new('-name' => 'generate',
 					    '-cl_option' => '-g',
 					    '-cl_alias' => '--generate',
@@ -250,15 +253,11 @@ $prLog->print('-kind' => 'E',
 	      '-exit' => 1)
     unless ($configFile or $backupDir);
 
-$prLog->print('-kind' => 'E',
-	      '-str' => ["target directory <$targetDir> does not exist"],
-	      '-exit' => 1)
-    unless (-d $targetDir);
-
 
 my $otherBackupSeries = undef;
 my $lateLinks = undef;
 my $lateCompress = undef;
+my $useOldConfig = 0;
 if ($configFile)    # get information from config file
 {
     my $confOld =
@@ -279,13 +278,26 @@ if ($configFile)    # get information from config file
 			    Option->new('-name' => 'lateCompress',
 					'-only_if' => '[lateLinks]',
 					'-cf_key' => 'lateCompress',
-					'-cf_noOptSet' => ['yes', 'no'])
+					'-cf_noOptSet' => ['yes', 'no']),
+			    Option->new('-name' => 'mergeBackupDir',
+					'-cf_key' => 'mergeBackupDir',
+					'-param' => 'yes'),
 			]);
     $confOld->check('-argv' => ['-f' => $configFile],
 		    '-help' => "cannot read file <$configFile>\n",
 		    '-ignoreAdditionalKeys' => 1);
 
-    $backupDir = $confOld->getOptWithPar('backupDir');
+    my $mergeBackupDir = $confOld->getOptWithPar('mergeBackupDir');
+    if ($mergeBackupDir)
+    {
+	$backupDir = $confOld->getOptWithPar('mergeBackupDir');
+	$targetDir = $confOld->getOptWithPar('backupDir');
+	$useOldConfig = 1;
+    }
+    else
+    {
+	$backupDir = $confOld->getOptWithPar('backupDir');
+    }
     $series = $confOld->getOptWithPar('series');
     $lateLinks = $confOld->getOptWithoutPar('lateLinks');
     $lateCompress = $confOld->getOptWithoutPar('lateCompress');
@@ -331,6 +343,14 @@ $prLog->print('-kind' => 'E',
 	      '-str' => ["backup directory <$backupDir> does not exist"],
 	      '-exit' => 1)
     unless (-d $backupDir);
+$prLog->print('-kind' => 'E',
+	      '-str' => ["please specify targetDir"],
+	      '-exit' => 1)
+    unless ($targetDir);
+$prLog->print('-kind' => 'E',
+	      '-str' => ["target directory <$targetDir> does not exist"],
+	      '-exit' => 1)
+    unless (-d $targetDir);
 $prLog->print('-kind' => 'E',
 	      '-str' =>
 	      ["series directory <$series> does not exist inside <$backupDir>"],
@@ -396,7 +416,8 @@ else
     $prLog->print('-kind' => 'E',
 		  '-str' =>
        ["last backupDir <$backupDir> needs to run storeBackupUpdateBackup.pl, " .
-	"please do so and repeat running this program"],
+	"please do so and repeat running this program" .
+	"or use option --explicitBackup"],
 		  '-exit' => 1)
 	if -e "$lastBackupDir/.storeBackupLinks/linkFile.bz2";
 
@@ -406,7 +427,7 @@ else
 	if $verbose;
 }
 
-if ($configFile)  # copy configuration file
+if ($configFile and not $useOldConfig)  # copy configuration file
 {
     unless ($generateConfigFile)
     {
@@ -597,7 +618,7 @@ $prLog->print('-kind' => 'I',
 $prLog->print('-kind' => 'I',
 	      '-str' =>
 	      ["you may want to adjust <$generateConfigFile> to your needs"])
-    if ($configFile);
+    if ($configFile and not $useOldConfig);
 
 
 exit 0;
