@@ -173,6 +173,10 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
     If set to the same file as in storeBackup it will
     prevent $prog from running in parallel
     to storeBackup, default is $lockFile
+    this type of lock files does not work across multiple servers
+    and is not designed to separate storeBackup.pl and
+    storeBackupUpdateBackup.pl or any other storeBackup
+    process in a separate PID space
 
 =item B<--noCompress>
 
@@ -329,7 +333,7 @@ my $CheckPar =
 					    '-cl_alias' => '--verbose'),
 				Option->new('-name' => 'debug',
 					    '-cl_option' => '--debug',
-					    '-cl_option' => '-d',
+					    '-cl_alias' => '-d',
 					    '-only_if' => 'not [interactive]'),
 				Option->new('-name' => 'logFile',
 					    '-cl_option' => '-l',
