@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2002-2009)
+#   Copyright (C) Heinz-Josef Claes (2002-2013)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -18,10 +18,9 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+use Fcntl qw(O_RDWR O_CREAT);
+use POSIX;
 
-my $VERSION = '$Id: storeBackup_du.pl 354 2009-03-15 08:39:18Z hjc $ ';
-push @VERSION, $VERSION;
-my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 use strict;
@@ -93,27 +92,45 @@ require 'version.pl';
 require 'humanRead.pl';
 require 'storeBackupLib.pl';
 
+=head1 NAME
 
-my $Help = <<EOH;
-This program evaluates the disk usage in one or more backup directories.
+storeBackup_du.pl - evaluates the disk usage in one or more backup directories.
 
-usage:
-	$0 [-v] [-l] backupdirs ...
+=head1 SYNOPSIS
 
---verbose  -v  Print accumulated values for multiple versions (days)
-	       of backuped files. Shows the steps when calculating the
-	       space used by the specified backups
---links	   -l  Also print statistic about how many links the files have
-	       and how much space this saves.
+    storeBackup_du.pl [-v] [-l] backupdirs ...
 
-Copyright (c) 2002-2008 by Heinz-Josef Claes (see README)
+=head1 OPTIONS
+
+=over 8
+
+=item B<--verbose>, B<-v>
+
+    Print accumulated values for multiple versions (days)
+    of backuped files. Shows the steps when calculating the
+    space used by the specified backups
+
+=item B<--links>, B<-l>
+
+    Also print statistic about how many links the files have
+    and how much space this saves.
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright (c) 2002-2013 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
-EOH
-    ;
+
+=cut
+
+my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
 die "$Help" unless @ARGV;
 
-&printVersions(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V');
 
 
 my $CheckPar =
@@ -134,7 +151,7 @@ $CheckPar->check('-argv' => \@ARGV,
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
 my $links = $CheckPar->getOptWithoutPar('links');
 
-print "$VERSIONpName, $main::STOREBACKUPVERSION, build $VERSIONsvnID\n"
+print "storeBackup_du.pl, $main::STOREBACKUPVERSION\n"
     if $verbose;
 
 die "directories missing in argument list"
