@@ -748,6 +748,45 @@ sub existStr
 }
 
 
+############################################################
+# creates sparse file with specified size
+# deletes existing file
+# returns 1 if success / returns 0 if no success
+sub createSparseFile
+{
+    my $file = shift;
+    my $size = shift;
+    my $prLog = shift;
+
+    if (-e $file)
+    {
+	return 0 if unlink $file != 1;
+    }
+
+    unless (sysopen(TO, $file, O_CREAT | O_WRONLY))
+    {
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot create sparse file <$file>"]);
+	return 0;
+    }
+
+    sysseek(TO, $size - 1, 0);
+
+    my $buffer = pack('C', 0);
+
+    unless (syswrite(TO, $buffer))
+    {
+	$prLog->print('-kind' => 'E',
+		      '-str' =>
+		      ["cannot syswrite when creating sparse file <$file>"]);
+	return 0;
+    }
+
+    close(TO);
+    return 1;
+}
+
+
 ############################################################
 # Objekt kann zum (wiederholten) Abfragen von Informationen
 # ber eine Datei verwendet werden.
