@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000-2012)
+#   Copyright (C) Heinz-Josef Claes (2000-2013)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -126,6 +126,15 @@ sub new
 
 
 ##################################################
+# creates a named pipe and forks lib/stbuLog.pl
+#  which reads from that pipe
+# for each call of print (__reallyPrint) checks if 
+#  lib/stbuLog.pl was forked. If yes, writes to named
+#  pipe created
+#
+# to be used if program is forked (not execed!)
+# if fork exec, write to namend pipe in execed program directly
+#  get the name of the fifo with getFifoName (see below)
 sub fork
 {
     my $self = shift;
@@ -174,6 +183,15 @@ sub fork
 }
 
 
+##################################################
+sub getFifoName
+{
+    my $self = shift;
+
+    return $self->{'fifo'};
+}
+
+
 ##################################################
 sub setStopAtNoMessages
 {
